==> barcode_scanner-0.9.0-rc.1.tar.gz: lib/barcode_scanning_data.dart <==
import 'package:flutter/cupertino.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:barcode_scanner/common_data.dart';
import 'package:barcode_scanner/sdk_utils.dart';

import 'common_data.dart';

part 'barcode_scanning_data.g.dart';

@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class BarcodeScanningResult extends Result {
  List<BarcodeItem> barcodeItems;

  Uri barcodeImageURI;

  BarcodeScanningResult(this.barcodeItems);

  BarcodeScanningResult.error(String message) {
    this.operationResult = OperationResult.ERROR;
    this.message = message;
  }

  factory BarcodeScanningResult.fromJson(Map<String, dynamic> json) =>
      _$BarcodeScanningResultFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeScanningResultToJson(this);
}

@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class BarcodeItem {
  ///Scanned barcode format
  BarcodeFormat barcodeFormat;

  ///Result data from barcode
  String text;

  factory BarcodeItem.fromJson(Map<String, dynamic> json) =>
      _$BarcodeItemFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeItemToJson(this);

  BarcodeItem(this.barcodeFormat, this.text);
}

///Available barcode formats
enum BarcodeFormat {
  AZTEC,
  CODABAR,
  CODE_39,
  CODE_93,
  CODE_128,
  DATA_MATRIX,
  EAN_8,
  EAN_13,
  ITF,
  PDF_417,
  QR_CODE,
  RSS_14,
  RSS_EXPANDED,
  UPC_A,
  UPC_E,
  UNKNOWN
}

class PredefinedBarcodes {
  ///return list of one dimensional barcode formats
  static List<BarcodeFormat> oneDimensionalBarcodes() {
    return [
      BarcodeFormat.CODE_128,
      BarcodeFormat.CODE_39,
      BarcodeFormat.CODE_93,
      BarcodeFormat.EAN_13,
      BarcodeFormat.EAN_8,
      BarcodeFormat.ITF,
      BarcodeFormat.UPC_E
    ];
  }

  ///return list of two dimensional barcode formats
  static List<BarcodeFormat> twoDimensionalBarcodes() {
    return [
      BarcodeFormat.AZTEC,
      BarcodeFormat.DATA_MATRIX,
      BarcodeFormat.PDF_417,
      BarcodeFormat.QR_CODE
    ];
  }
}

@JsonSerializable(nullable: true, includeIfNull: false, explicitToJson: true)
class BarcodeScannerConfiguration {
  /// Background color of the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color topBarBackgroundColor;

  /// Color of the titles of all buttons in the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color topBarButtonsColor;

  /// Background color outside of the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color cameraOverlayColor;

  /// Color of the finder window's outline.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color finderLineColor;

  /// Color of the text hint under the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color finderTextHintColor;

  ///color of active buttons on bottom bar
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color bottomButtonsActiveColor;

  ///color of inactive buttons on bottom bar
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color bottomButtonsInactiveColor;

  bool cancelButtonHidden;

  /// Title of the cancel button.
  String cancelButtonTitle;

  /// Title of the button that opens the screen where the user can allow
  /// the usage of the camera by the app.
  String enableCameraButtonTitle;

  /// Text that will be displayed when the app
  /// is not allowed to use the camera, prompting the user
  /// to enable the usage of the camera.
  String enableCameraExplanationText;

  /// Text hint shown under the finder window.
  String finderTextHint;

  String flashButtonTitle;

  /// Height of the finder window in pixels.
  int finderHeight;

  /// Width of the finder window in pixels.
  int finderWidth;

  /// Thickness of the finder window's outline.
  int finderLineWidth;

  /// Controls whether to play a beep sound after a successful detection.
  /// Default value is TRUE.
  bool successBeepEnabled;

  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool flashEnabled;

  /// Orientation lock mode of the camera: PORTRAIT or LANDSCAPE.
  /// By default the camera orientation is not locked.

  CameraOrientationMode orientationLockMode;

  /// Format of barcode which  need to recognize
  List<BarcodeFormat> barcodeFormats;

  /// Param that handle whether we need to save image from camera preview or make a snapshot while snapping barcode
  /// image uri will be returned in [BarcodeScanningResult.snappedImage] property
  BarcodeImageGenerationType barcodeImageGenerationType =
      BarcodeImageGenerationType.NONE;

  BarcodeScannerConfiguration(
      {this.topBarBackgroundColor,
        this.topBarButtonsColor,
        this.cameraOverlayColor,
        this.finderLineColor,
        this.finderTextHintColor,
        this.bottomButtonsActiveColor,
        this.bottomButtonsInactiveColor,
        this.cancelButtonTitle,
        this.enableCameraButtonTitle,
        this.enableCameraExplanationText,
        this.finderTextHint,
        this.flashButtonTitle,
        this.finderHeight,
        this.finderWidth,
        this.finderLineWidth,
        this.successBeepEnabled,
        this.flashEnabled,
        this.orientationLockMode,
        this.barcodeFormats,
        this.cancelButtonHidden,
        this.barcodeImageGenerationType});

  factory BarcodeScannerConfiguration.fromJson(Map<String, dynamic> json) =>
      _$BarcodeScannerConfigurationFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeScannerConfigurationToJson(this);
}

enum BarcodeImageGenerationType { NONE, VIDEO_FRAME, CAPTURED_IMAGE }

@JsonSerializable(nullable: true, includeIfNull: false, explicitToJson: true)
class DetectFromImageParams {
  ///file or content uri
  Uri uri;

  /// Enable more sensitive barcode detection.
  /// If set to true - will detect more barcodes.
  /// As a downside, might return false positives barcodes.
  /// Default is FALSE.
  bool enableHighSensitivityMode;

  /// Format of barcode which  need to recognize
  List<BarcodeFormat> barcodeFormats;

  DetectFromImageParams(this.uri, this.barcodeFormats, this.enableHighSensitivityMode);

  factory DetectFromImageParams.fromJson(Map<String, dynamic> json) =>
      _$DetectFromImageParamsFromJson(json);

  Map<String, dynamic> toJson() => _$DetectFromImageParamsToJson(this);
}

==> barcode_scanner-1.0.1.tar.gz: lib/barcode_scanning_data.dart <==
import 'package:flutter/cupertino.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:barcode_scanner/common_data.dart';
import 'package:barcode_scanner/sdk_utils.dart';

import 'common_data.dart';

part 'barcode_scanning_data.g.dart';

@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class BarcodeScanningResult extends Result {
  List<BarcodeItem> barcodeItems;

  Uri barcodeImageURI;

  BarcodeScanningResult(this.barcodeItems);

  BarcodeScanningResult.error(String message) {
    this.operationResult = OperationResult.ERROR;
    this.message = message;
  }

  factory BarcodeScanningResult.fromJson(Map<String, dynamic> json) =>
      _$BarcodeScanningResultFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeScanningResultToJson(this);
}

@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class BarcodeItem {
  ///Scanned barcode format
  BarcodeFormat barcodeFormat;

  ///Result data from barcode
  String text;

  factory BarcodeItem.fromJson(Map<String, dynamic> json) =>
      _$BarcodeItemFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeItemToJson(this);

  BarcodeItem(this.barcodeFormat, this.text);
}

///Available barcode formats
enum BarcodeFormat {
  AZTEC,
  CODABAR,
  CODE_39,
  CODE_93,
  CODE_128,
  DATA_MATRIX,
  EAN_8,
  EAN_13,
  ITF,
  PDF_417,
  QR_CODE,
  RSS_14,
  RSS_EXPANDED,
  UPC_A,
  UPC_E,
  UNKNOWN
}

class PredefinedBarcodes {
  ///return list of one dimensional barcode formats
  static List<BarcodeFormat> oneDimensionalBarcodes() {
    return [
      BarcodeFormat.CODE_128,
      BarcodeFormat.CODE_39,
      BarcodeFormat.CODE_93,
      BarcodeFormat.EAN_13,
      BarcodeFormat.EAN_8,
      BarcodeFormat.ITF,
      BarcodeFormat.UPC_E
    ];
  }

  ///return list of two dimensional barcode formats
  static List<BarcodeFormat> twoDimensionalBarcodes() {
    return [
      BarcodeFormat.AZTEC,
      BarcodeFormat.DATA_MATRIX,
      BarcodeFormat.PDF_417,
      BarcodeFormat.QR_CODE
    ];
  }
}

@JsonSerializable(nullable: true, includeIfNull: false, explicitToJson: true)
class BarcodeScannerConfiguration {
  /// Background color of the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color topBarBackgroundColor;

  /// Color of the titles of all buttons in the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color topBarButtonsColor;

  /// Background color outside of the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color cameraOverlayColor;

  /// Color of the finder window's outline.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color finderLineColor;

  /// Color of the text hint under the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color finderTextHintColor;

  ///color of active buttons on bottom bar
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color bottomButtonsActiveColor;

  ///color of inactive buttons on bottom bar
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color bottomButtonsInactiveColor;

  bool cancelButtonHidden;

  /// Title of the cancel button.
  String cancelButtonTitle;

  /// Title of the button that opens the screen where the user can allow
  /// the usage of the camera by the app.
  String enableCameraButtonTitle;

  /// Text that will be displayed when the app
  /// is not allowed to use the camera, prompting the user
  /// to enable the usage of the camera.
  String enableCameraExplanationText;

  /// Text hint shown under the finder window.
  String finderTextHint;

  String flashButtonTitle;

  /// Height of the finder window in pixels.
  int finderHeight;

  /// Width of the finder window in pixels.
  int finderWidth;

  /// Thickness of the finder window's outline.
  int finderLineWidth;

  /// Controls whether to play a beep sound after a successful detection.
  /// Default value is TRUE.
  bool successBeepEnabled;

  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool flashEnabled;

  /// Orientation lock mode of the camera: PORTRAIT or LANDSCAPE.
  /// By default the camera orientation is not locked.

  CameraOrientationMode orientationLockMode;

  /// Format of barcode which  need to recognize
  List<BarcodeFormat> barcodeFormats;

  /// Param that handle whether we need to save image from camera preview or make a snapshot while snapping barcode
  /// image uri will be returned in [BarcodeScanningResult.snappedImage] property
  BarcodeImageGenerationType barcodeImageGenerationType =
      BarcodeImageGenerationType.NONE;

  BarcodeScannerConfiguration(
      {this.topBarBackgroundColor,
      this.topBarButtonsColor,
      this.cameraOverlayColor,
      this.finderLineColor,
      this.finderTextHintColor,
      this.bottomButtonsActiveColor,
      this.bottomButtonsInactiveColor,
      this.cancelButtonTitle,
      this.enableCameraButtonTitle,
      this.enableCameraExplanationText,
      this.finderTextHint,
      this.flashButtonTitle,
      this.finderHeight,
      this.finderWidth,
      this.finderLineWidth,
      this.successBeepEnabled,
      this.flashEnabled,
      this.orientationLockMode,
      this.barcodeFormats,
      this.cancelButtonHidden,
      this.barcodeImageGenerationType});

  factory BarcodeScannerConfiguration.fromJson(Map<String, dynamic> json) =>
      _$BarcodeScannerConfigurationFromJson(json);

  Map<String, dynamic> toJson() => _$BarcodeScannerConfigurationToJson(this);
}

enum BarcodeImageGenerationType { NONE, VIDEO_FRAME, CAPTURED_IMAGE }

@JsonSerializable(nullable: true, includeIfNull: false, explicitToJson: true)
class DetectFromImageParams {
  ///file or content uri
  Uri uri;

  /// Enable more sensitive barcode detection.
  /// If set to true - will detect more barcodes.
  /// As a downside, might return false positives barcodes.
  /// Default is FALSE.
  bool enableHighSensitivityMode;

  /// Format of barcode which  need to recognize
  List<BarcodeFormat> barcodeFormats;

  DetectFromImageParams(
      this.uri, this.barcodeFormats, this.enableHighSensitivityMode);

  factory DetectFromImageParams.fromJson(Map<String, dynamic> json) =>
      _$DetectFromImageParamsFromJson(json);

  Map<String, dynamic> toJson() => _$DetectFromImageParamsToJson(this);
}
